@@ -1,6 +1,9 @@
 import re
 from base64 import b64decode
 from pathlib import Path
+from typing import List
+
+from luhn import verify as luhn_verify
 
 from whispers.utils import Secret, find_line_number, load_yaml_from_file, similar_strings
 
@@ -72,7 +75,7 @@ class WhisperRules:
                     return True
         return False
 
-    def check(self, key: str, value: str, filepath: Path) -> Secret:
+    def check(self, key: str, value: str, filepath: Path, foundlines: List[int]) -> Secret:
         matrix = {"key": key, "value": value}
         checks = {
             "minlen": self.check_minlen,
@@ -80,6 +83,7 @@ class WhisperRules:
             "isBase64": self.check_isBase64,
             "isAscii": self.check_isAscii,
             "isUri": self.check_isUri,
+            "isLuhn": self.check_isLuhn,
         }
         for rule_id, rule in self.rules.items():
             rule_matched = True
@@ -107,7 +111,7 @@ class WhisperRules:
                 continue
             return Secret(
                 filepath.as_posix(),
-                find_line_number(filepath, key, value),
+                find_line_number(filepath, key, value, foundlines),
                 key,
                 value,
                 self.rules[rule_id]["message"],
@@ -165,6 +169,12 @@ class WhisperRules:
             return False  # Not float
         return similar_strings(key, value) >= similar
 
+    @staticmethod
+    def check_isLuhn(rule, key, value):
+        if not value.isnumeric():
+            return False
+        return luhn_verify(value)
+
     @staticmethod
     def decode_if_base64(mkey, mvalue):
         if "isBase64" in mkey:
